# pyblinker
Tools for analyzing eye blinks from EEG data. This is Python alternative to the EEG-Blinks Matlab version that has been maintained by Vislab (https://github.com/VisLab/EEG-Blinks).

The package documentation is accessable at: http://vislab.github.io/EEG-Blinks/.

Due deligent has been made to ensure the EEG-Blinks-Python output similar result as the EEG-Blinks Matlab version.

In future version, this package is expected to able to handle both continous and epoch EEG signal.

# Installation

pip install eeg-blinks==0.0.1


